@@ -10,23 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
-$DATE = '2003/07/11';
+$VERSION = '0.03';
+$DATE = '2003/07/26';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_SubPM.pm' => [qw(0.02 2003/07/11), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'lib/File/SubPM.pm' => [qw(1.1 2003/07/04), 'unchanged'],
-    't/File/SubPM.d' => [qw(0.01 2003/07/07), 'unchanged'],
+    'lib/Docs/Site_SVD/File_SubPM.pm' => [qw(0.03 2003/07/26), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2003/07/26), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2003/07/26), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2003/07/26), 'generated, replaces 0.02'],
+    'lib/File/SubPM.pm' => [qw(1.11 2003/07/26), 'revised 1.1'],
+    't/File/SubPM.d' => [qw(0.02 2003/07/26), 'revised 0.01'],
     't/File/SubPM.pm' => [qw(0.01 2003/06/07), 'unchanged'],
-    't/File/SubPM.t' => [qw(0.01 2003/07/07), 'unchanged'],
+    't/File/SubPM.t' => [qw(0.08 2003/07/26), 'revised 0.07'],
     't/File/Drivers/Driver.pm' => [qw(0.02 2003/07/04), 'unchanged'],
     't/File/Drivers/Generate.pm' => [qw(0.02 2003/07/04), 'unchanged'],
     't/File/Drivers/IO.pm' => [qw(0.02 2003/07/04), 'unchanged'],
+    'tlib/File/Package.pm' => [qw(1.1 2003/07/26), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.1 2003/07/26), 'new'],
 
 );
 
@@ -53,11 +55,11 @@ use vars qw(%INVENTORY);
 
   File::SubPM - Process sub module names found in a sub directory
 
- Revision: A
+ Revision: B
 
- Version: 0.02
+ Version: 0.03
 
- Date: 2003/07/11
+ Date: 2003/07/26
 
  Prepared for: General Public 
 
@@ -93,7 +95,7 @@ of sub module names.
 
 =head2 1.3 Document overview.
 
-This document releases File::SubPM version 0.02
+This document releases File::SubPM version 0.03
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -109,8 +111,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-SubPM-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-SubPM-0.02
+   http://www.softwarediamonds/packages/File-SubPM-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-SubPM-0.03
 
 
 Restrictions regarding duplication and license provisions
@@ -178,17 +180,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_SubPM.pm                              0.02    2003/07/11 revised 0.01
- MANIFEST                                                     0.02    2003/07/11 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/07/11 generated, replaces 0.01
- README                                                       0.02    2003/07/11 generated, replaces 0.01
- lib/File/SubPM.pm                                            1.1     2003/07/04 unchanged
- t/File/SubPM.d                                               0.01    2003/07/07 unchanged
+ lib/Docs/Site_SVD/File_SubPM.pm                              0.03    2003/07/26 revised 0.02
+ MANIFEST                                                     0.03    2003/07/26 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2003/07/26 generated, replaces 0.02
+ README                                                       0.03    2003/07/26 generated, replaces 0.02
+ lib/File/SubPM.pm                                            1.11    2003/07/26 revised 1.1
+ t/File/SubPM.d                                               0.02    2003/07/26 revised 0.01
  t/File/SubPM.pm                                              0.01    2003/06/07 unchanged
- t/File/SubPM.t                                               0.01    2003/07/07 unchanged
+ t/File/SubPM.t                                               0.08    2003/07/26 revised 0.07
  t/File/Drivers/Driver.pm                                     0.02    2003/07/04 unchanged
  t/File/Drivers/Generate.pm                                   0.02    2003/07/04 unchanged
  t/File/Drivers/IO.pm                                         0.02    2003/07/04 unchanged
+ tlib/File/Package.pm                                         1.1     2003/07/26 new
+ tlib/Test/Tech.pm                                            1.1     2003/07/26 new
 
 
 =head2 3.3 Changes
@@ -197,11 +201,11 @@ Changes are as follows:
 
 =over 4
 
-=item Test::TestUtil 0.01
+=item Test-TestUtil-0.01
 
 Originated
 
-=item Test::TestUtil 0.02
+=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -226,7 +230,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-=item Test::TestUtil 0.03
+=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -256,7 +260,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-=item Test::TestUtil 0.04
+=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -286,7 +290,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
   File::SubPM - Process sub module names found in a sub directory
 
 
- Revision: A
+ Revision: B
 
 [snip]
 
@@ -321,7 +325,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-=item File::FileUtil 0.01
+=item File-FileUtil-0.01
 
 =over 4
 
@@ -376,11 +380,11 @@ failure from CPAN testing whose is running on a different platform.
 
 =back
 
-=item File::FileUtil 0.02
+=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-=item File::FileUtil 0.03
+=item File-FileUtil-0.03
 
 =over 4
 
@@ -399,7 +403,7 @@ the directories in @INC
 
 =back
 
-=item File::SubPM 0.01
+=item File-SubPM-0.01
 
 Removed the methods for converting a
 program module specification to its
@@ -409,21 +413,25 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
+=item File-SubPM-0.02
+
+=item File-SubPM-0.03
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 =back
 
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -451,17 +459,13 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-SubPM-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-SubPM-0.02
+   http://www.softwarediamonds/packages/File-SubPM-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-SubPM-0.03
 
 
 =item Prerequistes.
 
- 'File::SmartNL' => '0',
- 'File::Package' => '0',
- 'File::TestPath' => '0',
- 'Text::Scrub' => '0',
- 'Test::Tech' => '1.08',
+ None.
 
 
 =item Security, privacy, or safety precautions.
@@ -543,8 +547,13 @@ Plain Old Documentation
 
 =head1 2.0 SEE ALSO
 
- 
-L<File::SubPM|File::SubPM>
+=over 4
+
+=item L<File::SubPM|File::SubPM> 
+
+=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+=back
 
 =for html
 <hr>
@@ -571,11 +580,11 @@ __DATA__
 DISTNAME: File-SubPM^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.02^
+VERSION : 0.03^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: B^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 
@@ -607,15 +616,11 @@ AUTO_REVISE:
 lib/File/SubPM.pm
 t/File/SubPM.*
 t/File/Drivers/*
+lib/File/Package.pm => tlib/File/Package.pm
+lib/Test/Tech.pm => tlib/Test/Tech.pm
 ^
 
-PREREQ_PM:
-'File::SmartNL' => '0',
-'File::Package' => '0',
-'File::TestPath' => '0',
-'Text::Scrub' => '0',
-'Test::Tech' => '1.08',
-^
+PREREQ_PM:  ^
 
 TESTS: t/File/SubPM.t^
 
@@ -625,11 +630,11 @@ Changes are as follows:
 
 \=over 4
 
-\=item Test::TestUtil 0.01
+\=item Test-TestUtil-0.01
 
 Originated
 
-\=item Test::TestUtil 0.02
+\=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -654,7 +659,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-\=item Test::TestUtil 0.03
+\=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -684,7 +689,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-\=item Test::TestUtil 0.04
+\=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -749,7 +754,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-\=item File::FileUtil 0.01
+\=item File-FileUtil-0.01
 
 \=over 4
 
@@ -804,11 +809,11 @@ failure from CPAN testing whose is running on a different platform.
 
 \=back
 
-\=item File::FileUtil 0.02
+\=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-\=item File::FileUtil 0.03
+\=item File-FileUtil-0.03
 
 \=over 4
 
@@ -827,7 +832,7 @@ the directories in @INC
 
 \=back
 
-\=item File::SubPM 0.01
+\=item File-SubPM-0.01
 
 Removed the methods for converting a
 program module specification to its
@@ -837,6 +842,19 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
+\=item File-SubPM-0.02
+
+\=item File-SubPM-0.03
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 \=back
 
 ^
@@ -977,10 +995,18 @@ Plain Old Documentation
 \=back
 ^
 
-SEE_ALSO:  
-L<File::SubPM|File::SubPM>
+SEE_ALSO: 
+\=over 4
+
+\=item L<File::SubPM|File::SubPM> 
+
+\=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+\=back
+
 ^
 
+
 HTML:
 <hr>
 <p><br>
